﻿/*
Post-Deployment Script Template							
--------------------------------------------------------------------------------------
 This file contains SQL statements that will be appended to the build script.		
 Use SQLCMD syntax to include a file in the post-deployment script.			
 Example:      :r .\myfile.sql								
 Use SQLCMD syntax to reference a variable in the post-deployment script.		
 Example:      :setvar TableName MyTable							
               SELECT * FROM [$(TableName)]					
--------------------------------------------------------------------------------------
*/

/*******************************************************************
Set the recovery model to simple
*******************************************************************/
DECLARE @query nvarchar(100)
SET @query = 'ALTER DATABASE ' + DB_NAME() + ' SET RECOVERY SIMPLE'
EXEC sp_executesql @query
SET NOCOUNT ON

------------------------------------------------------------------------------------
-- Be sure we have the permissions column
------------------------------------------------------------------------------------
IF NOT EXISTS (SELECT column_name FROM INFORMATION_SCHEMA.columns WHERE table_name = 'Role' AND column_name = 'RolePermissions')
BEGIN
  ALTER TABLE [dbo].[Role] ADD RolePermissions int NULL
END
GO

------------------------------------------------------------------------------------
-- We're not using the role constraint any longer - we're using a bitmask
------------------------------------------------------------------------------------
IF EXISTS (SELECT * FROM sysobjects WHERE name = 'FK_RoleMapping_Role')
BEGIN
	ALTER TABLE [dbo].[RoleMapping] DROP CONSTRAINT [FK_RoleMapping_Role]
END
GO

-----------------------------------
-- Populate the role provider table
-----------------------------------
DECLARE @adminRoleID int
DECLARE @quarantineRoleID int
DECLARE @licenseRoleID int
DECLARE @configRoleID int
DECLARE @parametersRoleID int
DECLARE @installRoleID int
DECLARE @roleRoleID int
DECLARE @settingsRoleID int
DECLARE @commentsRoleID int
DECLARE @queriesRoleID int
DECLARE @userRoleID int
DECLARE @eamAdminID int
DECLARE @eamR5ID int
DECLARE @blockedGroupID int

------------------------------------------------------------------------------------
-- See if we need to create the Admin role
------------------------------------------------------------------------------------
SELECT @adminRoleID = RoleID FROM [dbo].[Role] WHERE RoleName = 'Admin'
IF @adminRoleID IS NOT NULL
BEGIN
	UPDATE [dbo].[Role] SET 
		RolePermissions = 0,
		RoleName = 'Unused'
		WHERE RoleName = 'Admin'
	PRINT 'Renaming existing Admin role ID ' + CONVERT(varchar(10), @adminRoleID)
END

------------------------------------------------------------------------------------
-- See if we need to replace the User role with the Quarantine role
------------------------------------------------------------------------------------
SELECT @userRoleID = RoleID FROM [dbo].[Role] WHERE RoleName = 'User'
IF @userRoleID IS NOT NULL
BEGIN
	PRINT 'Using existing User ID for Quarantine role ID ' 
	UPDATE [dbo].[Role] SET RoleName = 'Quarantine' WHERE RoleName = 'uSER'
END

SELECT @quarantineRoleID = RoleID FROM [dbo].[Role] WHERE RoleName = 'Quarantine'
IF @quarantineRoleID IS NULL
BEGIN
	PRINT 'Creating new Quarantine role ID'
	INSERT INTO [dbo].[Role] (RoleName, RoleIsDefault, RolePermissions) VALUES ('Quarantine', 0, 2)
	SELECT @quarantineRoleID = @@IDENTITY
END
ELSE
BEGIN
	PRINT 'Using existing Quarantine role ID ' + CONVERT(varchar(10), @quarantineRoleID)
	UPDATE [dbo].[Role] SET RolePermissions = 2 WHERE RoleName = 'Quarantine'
	SET @quarantineRoleID = @userRoleID
END

------------------------------------------------------------------------------------
-- See if we need to create the License role
------------------------------------------------------------------------------------
SELECT @licenseRoleID = RoleID FROM [dbo].[Role] WHERE RoleName = 'License'
IF @licenseRoleID IS NULL
BEGIN
	PRINT 'Creating new License role ID'
	INSERT INTO [dbo].[Role] (RoleName, RoleIsDefault, RolePermissions) VALUES ('License', 0, 4)
	SELECT @licenseRoleID = @@IDENTITY
END
ELSE
BEGIN
	PRINT 'Using existing License role ID ' + CONVERT(varchar(10), @licenseRoleID)
	UPDATE [dbo].[Role] SET RolePermissions = 4 WHERE RoleName = 'License'
END

------------------------------------------------------------------------------------
-- See if we need to create the Config role
------------------------------------------------------------------------------------
SELECT @configRoleID = RoleID FROM [dbo].[Role] WHERE RoleName = 'Configuration'
IF @configRoleID IS NULL
BEGIN
	PRINT 'Creating new Configuration role ID'
	INSERT INTO [dbo].[Role] (RoleName, RoleIsDefault, RolePermissions) VALUES ('Configuration', 0, 8)
	SELECT @configRoleID = @@IDENTITY
END
ELSE
BEGIN
	PRINT 'Using existing Configuration role ID ' + CONVERT(varchar(10), @configRoleID)
	UPDATE [dbo].[Role] SET RolePermissions = 8 WHERE RoleName = 'Configuration'
END

------------------------------------------------------------------------------------
-- See if we need to create the Install Parameter role
------------------------------------------------------------------------------------
SELECT @parametersRoleID = RoleID FROM [dbo].[Role] WHERE RoleName = 'Parameters'
IF @parametersRoleID IS NULL
BEGIN
	PRINT 'Creating new Parameters role ID'
	INSERT INTO [dbo].[Role] (RoleName, RoleIsDefault, RolePermissions) VALUES ('Parameters', 0, 16)
	SELECT @parametersRoleID = @@IDENTITY
END
ELSE
BEGIN
	PRINT 'Using existing Parameters role ID ' + CONVERT(varchar(10), @parametersRoleID)
	UPDATE [dbo].[Role] SET RolePermissions = 16 WHERE RoleName = 'Parameters'
END

------------------------------------------------------------------------------------
-- See if we need to create the Installs role
------------------------------------------------------------------------------------
SELECT @installRoleID = RoleID FROM [dbo].[Role] WHERE RoleName = 'Installs'
IF @installRoleID IS NULL
BEGIN
	PRINT 'Creating new Installs role ID'
	INSERT INTO [dbo].[Role] (RoleName, RoleIsDefault, RolePermissions) VALUES ('Installs', 0, 32)
	SELECT @installRoleID = @@IDENTITY
END
ELSE
BEGIN
	PRINT 'Using existing Installs role ID ' + CONVERT(varchar(10), @installRoleID)
	UPDATE [dbo].[Role] SET RolePermissions = 32 WHERE RoleName = 'Installs'
END

------------------------------------------------------------------------------------
-- See if we need to create the Roles role
------------------------------------------------------------------------------------
SELECT @roleRoleID = RoleID FROM [dbo].[Role] WHERE RoleName = 'Roles'
IF @roleRoleID IS NULL
BEGIN
	PRINT 'Creating new Roles role ID'
	INSERT INTO [dbo].[Role] (RoleName, RoleIsDefault, RolePermissions) VALUES ('Roles', 0, 64)
	SELECT @roleRoleID = @@IDENTITY
END
ELSE
BEGIN
	PRINT 'Using existing Roles role ID ' + CONVERT(varchar(10), @roleRoleID)
	UPDATE [dbo].[Role] SET RolePermissions = 64 WHERE RoleName = 'Roles'
END

------------------------------------------------------------------------------------
-- See if we need to create the Settings role
------------------------------------------------------------------------------------
SELECT @settingsRoleID = RoleID FROM [dbo].[Role] WHERE RoleName = 'Settings'
IF @settingsRoleID IS NULL
BEGIN
	PRINT 'Creating new Settings role ID'
	INSERT INTO [dbo].[Role] (RoleName, RoleIsDefault, RolePermissions) VALUES ('Settings', 0, 128)
	SELECT @settingsRoleID = @@IDENTITY
END
ELSE
BEGIN
	PRINT 'Using existing Settings role ID ' + CONVERT(varchar(10), @settingsRoleID)
	UPDATE [dbo].[Role] SET RolePermissions = 128 WHERE RoleName = 'Settings'
END

------------------------------------------------------------------------------------
-- See if we need to create the StandardComments role
------------------------------------------------------------------------------------
SELECT @commentsRoleID = RoleID FROM [dbo].[Role] WHERE RoleName = 'StandardComments'
IF @commentsRoleID IS NULL
BEGIN
	PRINT 'Creating new StandardComments role ID'
	INSERT INTO [dbo].[Role] (RoleName, RoleIsDefault, RolePermissions) VALUES ('StandardComments', 0, 256)
	SELECT @commentsRoleID = @@IDENTITY
END
ELSE
BEGIN
	PRINT 'Using existing StandardComments role ID ' + CONVERT(varchar(10), @commentsRoleID)
	UPDATE [dbo].[Role] SET RolePermissions = 256 WHERE RoleName = 'StandardComments'
END

------------------------------------------------------------------------------------
-- See if we need to create the DeviceSyncQueries role
------------------------------------------------------------------------------------
SELECT @queriesRoleID = RoleID FROM [dbo].[Role] WHERE RoleName = 'DeviceSyncQueries'
IF @queriesRoleID IS NULL
BEGIN
	PRINT 'Creating new DeviceSyncQueries role ID'
	INSERT INTO [dbo].[Role] (RoleName, RoleIsDefault, RolePermissions) VALUES ('DeviceSyncQueries', 0, 512)
	SELECT @queriesRoleID = @@IDENTITY
END
ELSE
BEGIN
	PRINT 'Using existing DeviceSyncQueries role ID ' + CONVERT(varchar(10), @queriesRoleID)
	UPDATE [dbo].[Role] SET RolePermissions = 512 WHERE RoleName = 'DeviceSyncQueries'
END

------------------------------------------------------------------------------------
-- Clear the roles for any blocked groups
------------------------------------------------------------------------------------
SELECT @blockedGroupID = RoleID FROM [dbo].[Role] WHERE RoleName = 'Block'
IF @blockedGroupID IS NOT NULL
BEGIN
	UPDATE [dbo].[Role] SET RolePermissions = 0 WHERE RoleName = 'Block'
END

------------------------------------------------------------------------------------
-- Populate the group table
------------------------------------------------------------------------------------
IF NOT EXISTS (SELECT 1 FROM [dbo].[EAMGroup] WHERE EAMGroupName = 'Administrator')
BEGIN
	PRINT 'Creating new administrator group'
	INSERT INTO [dbo].[EAMGroup] VALUES ('Administrator')
	SELECT @eamAdminID = @@IDENTITY
END
ELSE
BEGIN
	SELECT @eamAdminID = EAMGroupID FROM [dbo].[EAMGroup] WHERE EAMGroupName = 'Administrator'
	PRINT 'Using existing administrator group ' + CONVERT(varchar(10), @eamAdminID)
END

IF NOT EXISTS (SELECT 1 FROM [dbo].[EAMGroup] WHERE EAMGroupName = 'R5')
BEGIN
	PRINT 'Creating new R5 group'
	INSERT INTO [dbo].[EAMGroup] VALUES ('R5')
	SELECT @eamR5ID = @@IDENTITY
END
ELSE
BEGIN
	SELECT @eamR5ID = EAMGroupID FROM [dbo].[EAMGroup] WHERE EAMGroupName = 'R5'
	PRINT 'Using existing administrator group ' + CONVERT(varchar(10), @eamR5ID)
END

------------------------------------------------------------------------------------
-- Populate the user table
------------------------------------------------------------------------------------
IF NOT EXISTS (SELECT 1 FROM [dbo].[User] WHERE UserName = 'Administrator')
BEGIN
	PRINT 'Creating new administrator user'
	INSERT INTO [dbo].[User] (UserName, EAMGroupID) VALUES ('Administrator', @eamAdminID)
END
ELSE
BEGIN
	PRINT 'Administrator user already exists'
END

IF NOT EXISTS (SELECT 1 FROM [dbo].[User] WHERE UserName = 'BDS')
BEGIN
	PRINT 'Creating new BDS user'
	INSERT INTO [dbo].[User] (UserName, EAMGroupID) VALUES ('BDS', @eamAdminID)
END
ELSE
BEGIN
	PRINT 'BDS user already exists'
END

------------------------------------------------------------------------------------
-- Populate the role mapping table
------------------------------------------------------------------------------------
IF NOT EXISTS (SELECT 1 FROM [dbo].[RoleMapping] WHERE EAMGroupId = @eamAdminID)
BEGIN
	PRINT 'Creating new default user'
	INSERT INTO [dbo].[RoleMapping] (RoleId, EAMGroupID) VALUES (0xFFFF, @eamAdminID)
END
ELSE
BEGIN
	PRINT 'Default user already exists'
END
IF NOT EXISTS (SELECT 1 FROM [dbo].[RoleMapping] WHERE EAMGroupId = @eamR5ID)
BEGIN
	PRINT 'Creating new default user'
	INSERT INTO [dbo].[RoleMapping] (RoleId, EAMGroupID) VALUES (0xFFFF, @eamR5ID)
END

GO
-- =============================================
-- Update the install state of each module that was just installed
-- =============================================

-------------------------------------------------------------------------------
-- Work Order Management
-------------------------------------------------------------------------------
DECLARE @WorkInstalled bit
DECLARE @WorkModuleId int
SET @WorkModuleId = 1
SET @WorkInstalled = 0

IF(NOT EXISTS (SELECT * FROM [dbo].[Module] WHERE [ModuleId] = @WorkModuleId))
BEGIN
	INSERT INTO [dbo].[Module] ([ModuleId],[Installed],[Name],[Version],[LicenseKey],[NumberOfDeviceLicenses],[InstallPath])
     VALUES (@WorkModuleId,@WorkInstalled,'Work Order Management','%WorkVersion%',NULL,NULL,'%WorkInstallPath%')
END
ELSE
BEGIN
	UPDATE [dbo].[Module]
    SET [Installed] = @WorkInstalled, [Version] = '%WorkVersion%', [InstallPath] = '%WorkInstallPath%'
	WHERE  [ModuleId] = @WorkModuleId
END

-------------------------------------------------------------------------------
-- Inventory Management
-------------------------------------------------------------------------------
DECLARE @InventoryInstalled bit
DECLARE @InventoryModuleId int
SET @InventoryModuleId = 2
SET @InventoryInstalled = 0

IF(NOT EXISTS (SELECT * FROM [dbo].[Module] WHERE [ModuleId] = @InventoryModuleId))
BEGIN
	INSERT INTO [dbo].[Module] ([ModuleId],[Installed],[Name],[Version],[LicenseKey],[NumberOfDeviceLicenses],[InstallPath])
     VALUES (@InventoryModuleId,@InventoryInstalled,'Inventory Management','%InventoryVersion%',NULL,NULL,'%InventoryInstallPath%')
END
ELSE
BEGIN
	UPDATE [dbo].[Module]
    SET [Installed] = @InventoryInstalled, [Version] = '%InventoryVersion%', [InstallPath] = '%InventoryInstallPath%'
	WHERE  [ModuleId] = @InventoryModuleId
END

-------------------------------------------------------------------------------
-- Inspections
-------------------------------------------------------------------------------
DECLARE @InspectionsModuleId int
SET @InspectionsModuleId = 3

IF(NOT EXISTS (SELECT * FROM [dbo].[Module] WHERE [ModuleId] = @InspectionsModuleId))
BEGIN
	INSERT INTO [dbo].[Module] ([ModuleId],[Installed],[Name],[Version],[LicenseKey],[NumberOfDeviceLicenses],[InstallPath])
     VALUES (@InspectionsModuleId,@WorkInstalled,'Inspections','%WorkVersion%',NULL,NULL,'%WorkInstallPath%')
END
ELSE
BEGIN
	UPDATE [dbo].[Module]
    SET [Installed] = @WorkInstalled, [Version] = '%WorkVersion%', [InstallPath] = '%WorkInstallPath%'
	WHERE  [ModuleId] = @InspectionsModuleId
END

-------------------------------------------------------------------------------
-- Work Order Management & Inspections
-------------------------------------------------------------------------------
DECLARE @WorkInspectionsModuleId int
SET @WorkInspectionsModuleId = 4

IF(NOT EXISTS (SELECT * FROM [dbo].[Module] WHERE [ModuleId] = @WorkInspectionsModuleId))
BEGIN
	INSERT INTO [dbo].[Module] ([ModuleId],[Installed],[Name],[Version],[LicenseKey],[NumberOfDeviceLicenses],[InstallPath])
     VALUES (@WorkInspectionsModuleId,@WorkInstalled,'Work Order Management & Inspections','%WorkVersion%',NULL,NULL,'%WorkInstallPath%')
END
ELSE
BEGIN
	UPDATE [dbo].[Module]
    SET [Installed] = @WorkInstalled, [Version] = '%WorkVersion%', [InstallPath] = '%WorkInstallPath%'
	WHERE  [ModuleId] = @WorkInspectionsModuleId
END

-------------------------------------------------------------------------------
-- E-Signature Support
-------------------------------------------------------------------------------
DECLARE @ESignatureModuleId int
SET @ESignatureModuleId = 5

-- Note: use Work Mgmt variables and string tokens b/c E-Signature only works with Work Mgmt at this time.

IF(NOT EXISTS (SELECT * FROM [dbo].[Module] WHERE [ModuleId] = @ESignatureModuleId))
BEGIN
	INSERT INTO [dbo].[Module] ([ModuleId],[Installed],[Name],[Version],[LicenseKey],[NumberOfDeviceLicenses],[InstallPath])
     VALUES (@ESignatureModuleId,@WorkInstalled,'E-Signature Support','%WorkVersion%',NULL,NULL,'%WorkInstallPath%')
END
ELSE
BEGIN
	UPDATE [dbo].[Module]
    SET [Installed] = @WorkInstalled, [Version] = '%WorkVersion%', [InstallPath] = '%WorkInstallPath%'
	WHERE  [ModuleId] = @ESignatureModuleId
END

-------------------------------------------------------------------------------
-- Advanced Mobile GIS Add-On
-------------------------------------------------------------------------------
DECLARE @GisModuleId int
SET @GisModuleId = 6

-- Note: use Work Mgmt variables and string tokens b/c GIS only works with Work Mgmt at this time.

IF(NOT EXISTS (SELECT * FROM [dbo].[Module] WHERE [ModuleId] = @GisModuleId))
BEGIN
	INSERT INTO [dbo].[Module] ([ModuleId],[Installed],[Name],[Version],[LicenseKey],[NumberOfDeviceLicenses],[InstallPath])
     VALUES (@GisModuleId,@WorkInstalled,'Advanced Mobile GIS Add-On','%WorkVersion%',NULL,NULL,'%WorkInstallPath%')
END
ELSE
BEGIN
	UPDATE [dbo].[Module]
    SET [Installed] = @WorkInstalled, [Version] = '%WorkVersion%', [InstallPath] = '%WorkInstallPath%'
	WHERE  [ModuleId] = @GisModuleId
END

-------------------------------------------------------------------------------
-- Advanced Mobile Work & Asset Management
-------------------------------------------------------------------------------
DECLARE @WorkAndAssetModuleId int
SET @WorkAndAssetModuleId = 7

IF(NOT EXISTS (SELECT * FROM [dbo].[Module] WHERE [ModuleId] = @WorkAndAssetModuleId))
BEGIN
	INSERT INTO [dbo].[Module] ([ModuleId],[Installed],[Name],[Version],[LicenseKey],[NumberOfDeviceLicenses],[InstallPath])
     VALUES (@WorkAndAssetModuleId,@WorkInstalled,'Work and Asset Management','%WorkVersion%',NULL,NULL,'%WorkInstallPath%')
END
ELSE
BEGIN
	UPDATE [dbo].[Module]
    SET [Installed] = @WorkInstalled, [Version] = '%WorkVersion%', [InstallPath] = '%WorkInstallPath%'
	WHERE  [ModuleId] = @WorkAndAssetModuleId
END
-- =============================================
-- Set permissions on the database for the configured service user
-- =============================================

IF NOT EXISTS (SELECT * FROM master.dbo.syslogins WHERE loginname = N'$(Login)')
CREATE LOGIN [$(Login)] FROM WINDOWS
GO
GRANT CONNECT TO [$(Login)]
GO
BEGIN TRY
EXEC sp_addrolemember N'db_owner', N'$(Login)'
END TRY
BEGIN CATCH
END CATCH
GO


